﻿/*! \file TransferFunctionEditorWindow.cs
 * \brief Changes camera view and zoom on user input.
 */

using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.EventSystems;

public class CameraController : MonoBehaviour
{

    public float rotXSpeed = 3.0f;
    public float rotYSpeed = 3.0f;
    public float scrollSpeed = 0.4f;

    private float rotX = 0, rotY = 0;
    private float distance = 2.0f;


    /// <summary>
    /// Updates the camera view on scroll and mouse click.
    /// </summary>
    void Update()
    {
        bool uiCcontrolsInUse = EventSystem.current.currentSelectedGameObject;
        if (uiCcontrolsInUse)
            return;

        Transform transform = GetComponent<Transform>();

        float effectiveScrollSpeed = scrollSpeed * (1 + distance * distance);
        distance -= Input.GetAxis("MouseScrollWheel") * effectiveScrollSpeed;
        distance = Mathf.Max(distance, 0.01f);

        // Debug.Log(scrollSpeed + ", " + effectiveScrollSpeed);

        if (Input.GetMouseButton(0))
        {
            rotY += Input.GetAxis("MouseX") * rotXSpeed;
            rotX -= Input.GetAxis("MouseY") * rotYSpeed;
        }

        Quaternion rotation = Quaternion.Euler(rotX, rotY, 0);
        Vector3 position = rotation * new Vector3(0.0f, 0.0f, -distance);

        transform.rotation = rotation;
        transform.position = position;
    }
}
