﻿/*! \file UIController.cs
 * \brief Controls UI input.
 */

using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

/// <summary>
/// Controller for UI elements.
/// </summary>
public class UIController : MonoBehaviour
{

    public Controller controller;
    public Dropdown presetDropdown;
    public RawImage transferFunctionImage;

    /// <summary>
    /// Called before first frame update.
    /// </summary>
    void Start()
    {
        presetDropdown.ClearOptions();

        var options = new List<string>();
        foreach (var preset in controller.presets)
            options.Add(preset.name);

        presetDropdown.AddOptions(options);

        SelectPreset(presetDropdown);

        controller.SetLerp(0);
        controller.SetBias(0);
        controller.SetShadingIntensity(0.1f);
    }

    /// <summary>
    /// Called when data file is changed through UI.
    /// </summary>
    public void SelectPreset(Dropdown dropdown)
    {
        int index = dropdown.value;
        controller.SelectPreset(index);

        var preset = controller.presets[index];
        Texture2D tf = preset.transferTex;
        transferFunctionImage.texture = tf;
    }

    /// <summary>
    /// Called when value is changed on blending slider.
    /// </summary>
    public void Lerp(Slider slider)
    {
        controller.SetLerp(slider.value);
    }

    /// <summary>
    /// Called when value is changed on bias slider.
    /// </summary>
    public void Bias(Slider slider)
    {
        controller.SetBias(slider.value);
    }

    /// <summary>
    /// Called when value is changed on intensity slider.
    /// </summary>
    public void ShadingIntensity(Slider slider)
    {
        controller.SetShadingIntensity(slider.value);
    }
}
