﻿/// (Internal) Testing the blending algorithm with two colors
Shader "Custom/BlendTest"
{
	Properties
	{
		_Color1("Color 1 (Bottom)", Color) = (1, 0, 0, 1)
		_Color2("Color 2 (Top)", Color) = (0, 1, 1, 1)
		_Lerp("Lerp between normal / hue-preserving", Range(0, 1)) = 0
		_Lab("Use lab", Range(0, 1)) = 0
	}
	
	SubShader
	{
		Tags { "Queue" = "Transparent" "RenderType" = "Transparent" }

		Pass
		{
			Cull Back
			ZWrite Off
			Blend SrcAlpha OneMinusSrcAlpha

			CGPROGRAM
			#pragma vertex vert
			#pragma fragment frag

			//#pragma exclude_renderers d3d9
			//#pragma exclude_renderers d3d11_9x

			#include "UnityCG.cginc"
			#include "functions.cginc"

			uniform float4 _Color1;
			uniform float4 _Color2;
			uniform float _Lerp;
			uniform float _Lab;

			struct AppData
			{
				float4 position : POSITION;
				float2 uv : TEXCOORD0;
			};

			struct VertexData
			{
				float4 position : SV_POSITION;
				float2 uv : TEXCOORD0;
				float3 localPosition : TEXCOORD1;
				float4 screenUv : TEXCOORD2;
			};

			VertexData vert(AppData appData)
			{
				VertexData vertexData;
				vertexData.position = UnityObjectToClipPos(appData.position);
				vertexData.uv = appData.uv;
				vertexData.localPosition = appData.position;
				vertexData.screenUv = ComputeScreenPos(vertexData.position);

				return vertexData;
			}

			float4 frag(VertexData vertexData) : SV_Target
			{
				//return float4(HSVtoRGB(float3(86.0 / 360.0, 0.85, 0.62)), 1.0);
				//return float4(HSVtoRGB(RGBtoHSV(float3(0.62, 0.10, 0.84))), 1.0);
				//return float4(oppositeColor(_Color1.rgb, _Color1.rgb), 1.0);

				// return float4(vertexData.uv.y, 0, 0, 1);
				// return float4(lerp(color1, color2, blendFactor), 1.0);

				float alpha = vertexData.uv.y;
				float4 color1 = _Color1;
				float4 color2 = _Color2;
				
				color1.rgb *= alpha;
				color2 *= (1 - alpha);

				float4 resultTrad = color1 + color2;

				float4 resultHuePres = float4(
					huePreservingColorAdd(color1, color2),
					1.0
				);

				return lerp(resultTrad, resultHuePres, _Lerp);
			}

			ENDCG
		}
	}
}