﻿/// This shader sets up ray start and end positions in two passes
/// 1. render front faces = ray start pos
/// 2. render back faces = ray end pos
Shader "Custom/VolumeRayData"
{
	Properties
	{
	}
	
	SubShader
	{
		Pass
		{
			CGPROGRAM
			#pragma vertex vert
			#pragma fragment frag

			#include "UnityCG.cginc"

			struct AppData
			{
				float4 position : POSITION;
			};

			struct VertexData
			{
				float4 position : SV_POSITION;
				float3 localPosition : TEXCOORD0;
			};

			VertexData vert(AppData appData)
			{
				VertexData vertexData;
				vertexData.position = UnityObjectToClipPos(appData.position);
				vertexData.localPosition = appData.position;

				return vertexData;
			}

			float4 frag(VertexData vertexData) : SV_Target
			{
				return float4(vertexData.localPosition, 1.0);
				//return float4(1, 0, 0, 1.0);
			}

			ENDCG
		}

		Pass
		{
			Cull Front

			CGPROGRAM
			#pragma vertex vert
			#pragma fragment frag

			#include "UnityCG.cginc"

			uniform sampler2D _RayStartPos;

			struct AppData
			{
				float4 position : POSITION;
			};

			struct VertexData
			{
				float4 position : SV_POSITION;
				float3 localPosition : TEXCOORD0;
				float4 screenUv : TEXCOORD1;
			};

			VertexData vert(AppData appData)
			{
				VertexData vertexData;
				vertexData.position = UnityObjectToClipPos(appData.position);
				vertexData.localPosition = appData.position;
				vertexData.screenUv = ComputeScreenPos(vertexData.position);

				return vertexData;
			}

			float4 frag(VertexData vertexData) : SV_Target
			{
				float2 screenUv = vertexData.screenUv.xy / vertexData.screenUv.w;
				float3 rayOrig = tex2D(_RayStartPos, screenUv).rgb;

				if (length(rayOrig) == 0.0) 
				{
					//float3 camRay = ObjSpaceViewDir(vertexData.localPosition);
					rayOrig = mul(unity_WorldToObject, float4(_WorldSpaceCameraPos, 1.0)).xyz;
				}

				float3 rayDir = vertexData.localPosition - rayOrig;

				//return float4(normalize(rayDir), length(rayDir));
				//return float4(length(rayDir));

				return float4(vertexData.localPosition, 1.0);
				//return float4(1, 0, 0, 1.0);
			}

			ENDCG
		}
	}
}